# coding: utf-8

# flake8: noqa

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from assisted_service_client.api.events_api import EventsApi
from assisted_service_client.api.installer_api import InstallerApi
from assisted_service_client.api.managed_domains_api import ManagedDomainsApi
from assisted_service_client.api.manifests_api import ManifestsApi
from assisted_service_client.api.operators_api import OperatorsApi
from assisted_service_client.api.versions_api import VersionsApi

# import ApiClient
from assisted_service_client.api_client import ApiClient
from assisted_service_client.configuration import Configuration
# import models into sdk package
from assisted_service_client.models.api_vip import ApiVip
from assisted_service_client.models.api_vip_connectivity_additional_request_header import ApiVipConnectivityAdditionalRequestHeader
from assisted_service_client.models.api_vip_connectivity_request import ApiVipConnectivityRequest
from assisted_service_client.models.api_vip_connectivity_response import ApiVipConnectivityResponse
from assisted_service_client.models.architecture_support_level_id import ArchitectureSupportLevelId
from assisted_service_client.models.bind_host_params import BindHostParams
from assisted_service_client.models.boot import Boot
from assisted_service_client.models.cluster import Cluster
from assisted_service_client.models.cluster_create_params import ClusterCreateParams
from assisted_service_client.models.cluster_default_config import ClusterDefaultConfig
from assisted_service_client.models.cluster_finalizing_progress import ClusterFinalizingProgress
from assisted_service_client.models.cluster_host_requirements import ClusterHostRequirements
from assisted_service_client.models.cluster_host_requirements_details import ClusterHostRequirementsDetails
from assisted_service_client.models.cluster_host_requirements_list import ClusterHostRequirementsList
from assisted_service_client.models.cluster_list import ClusterList
from assisted_service_client.models.cluster_network import ClusterNetwork
from assisted_service_client.models.cluster_progress_info import ClusterProgressInfo
from assisted_service_client.models.cluster_validation_id import ClusterValidationId
from assisted_service_client.models.completion_params import CompletionParams
from assisted_service_client.models.connectivity_check_host import ConnectivityCheckHost
from assisted_service_client.models.connectivity_check_nic import ConnectivityCheckNic
from assisted_service_client.models.connectivity_check_params import ConnectivityCheckParams
from assisted_service_client.models.connectivity_remote_host import ConnectivityRemoteHost
from assisted_service_client.models.connectivity_report import ConnectivityReport
from assisted_service_client.models.container_image_availability import ContainerImageAvailability
from assisted_service_client.models.container_image_availability_request import ContainerImageAvailabilityRequest
from assisted_service_client.models.container_image_availability_response import ContainerImageAvailabilityResponse
from assisted_service_client.models.container_image_availability_result import ContainerImageAvailabilityResult
from assisted_service_client.models.cpu import Cpu
from assisted_service_client.models.create_manifest_params import CreateManifestParams
from assisted_service_client.models.credentials import Credentials
from assisted_service_client.models.dhcp_allocation_request import DhcpAllocationRequest
from assisted_service_client.models.dhcp_allocation_response import DhcpAllocationResponse
from assisted_service_client.models.disk import Disk
from assisted_service_client.models.disk_config_params import DiskConfigParams
from assisted_service_client.models.disk_encryption import DiskEncryption
from assisted_service_client.models.disk_info import DiskInfo
from assisted_service_client.models.disk_installation_eligibility import DiskInstallationEligibility
from assisted_service_client.models.disk_role import DiskRole
from assisted_service_client.models.disk_skip_formatting_params import DiskSkipFormattingParams
from assisted_service_client.models.disk_speed import DiskSpeed
from assisted_service_client.models.disk_speed_check_request import DiskSpeedCheckRequest
from assisted_service_client.models.disk_speed_check_response import DiskSpeedCheckResponse
from assisted_service_client.models.domain_resolution_request import DomainResolutionRequest
from assisted_service_client.models.domain_resolution_response import DomainResolutionResponse
from assisted_service_client.models.domain_resolution_response_resolutions import DomainResolutionResponseResolutions
from assisted_service_client.models.download_boot_artifacts_request import DownloadBootArtifactsRequest
from assisted_service_client.models.drive_type import DriveType
from assisted_service_client.models.error import Error
from assisted_service_client.models.event import Event
from assisted_service_client.models.event_list import EventList
from assisted_service_client.models.feature_support_level_id import FeatureSupportLevelId
from assisted_service_client.models.finalizing_stage import FinalizingStage
from assisted_service_client.models.free_addresses_list import FreeAddressesList
from assisted_service_client.models.free_addresses_request import FreeAddressesRequest
from assisted_service_client.models.free_network_addresses import FreeNetworkAddresses
from assisted_service_client.models.free_networks_addresses import FreeNetworksAddresses
from assisted_service_client.models.gpu import Gpu
from assisted_service_client.models.host import Host
from assisted_service_client.models.host_create_params import HostCreateParams
from assisted_service_client.models.host_ignition_params import HostIgnitionParams
from assisted_service_client.models.host_list import HostList
from assisted_service_client.models.host_network import HostNetwork
from assisted_service_client.models.host_progress import HostProgress
from assisted_service_client.models.host_progress_info import HostProgressInfo
from assisted_service_client.models.host_registration_response import HostRegistrationResponse
from assisted_service_client.models.host_registration_response_next_step_runner_command import HostRegistrationResponseNextStepRunnerCommand
from assisted_service_client.models.host_role import HostRole
from assisted_service_client.models.host_role_update_params import HostRoleUpdateParams
from assisted_service_client.models.host_stage import HostStage
from assisted_service_client.models.host_static_network_config import HostStaticNetworkConfig
from assisted_service_client.models.host_type_hardware_requirements import HostTypeHardwareRequirements
from assisted_service_client.models.host_type_hardware_requirements_wrapper import HostTypeHardwareRequirementsWrapper
from assisted_service_client.models.host_update_params import HostUpdateParams
from assisted_service_client.models.host_validation_id import HostValidationId
from assisted_service_client.models.ignition_endpoint import IgnitionEndpoint
from assisted_service_client.models.ignition_endpoint_http_headers_params import IgnitionEndpointHttpHeadersParams
from assisted_service_client.models.ignored_validations import IgnoredValidations
from assisted_service_client.models.image_create_params import ImageCreateParams
from assisted_service_client.models.image_info import ImageInfo
from assisted_service_client.models.image_type import ImageType
from assisted_service_client.models.import_cluster_params import ImportClusterParams
from assisted_service_client.models.infra_env import InfraEnv
from assisted_service_client.models.infra_env_create_params import InfraEnvCreateParams
from assisted_service_client.models.infra_env_list import InfraEnvList
from assisted_service_client.models.infra_env_update_params import InfraEnvUpdateParams
from assisted_service_client.models.infra_error import InfraError
from assisted_service_client.models.ingress_cert_params import IngressCertParams
from assisted_service_client.models.ingress_vip import IngressVip
from assisted_service_client.models.inline_response200 import InlineResponse200
from assisted_service_client.models.inline_response2001 import InlineResponse2001
from assisted_service_client.models.install_cmd_request import InstallCmdRequest
from assisted_service_client.models.installer_args_params import InstallerArgsParams
from assisted_service_client.models.interface import Interface
from assisted_service_client.models.inventory import Inventory
from assisted_service_client.models.io_perf import IoPerf
from assisted_service_client.models.ip import Ip
from assisted_service_client.models.iscsi import Iscsi
from assisted_service_client.models.kernel_argument import KernelArgument
from assisted_service_client.models.kernel_arguments import KernelArguments
from assisted_service_client.models.l2_connectivity import L2Connectivity
from assisted_service_client.models.l3_connectivity import L3Connectivity
from assisted_service_client.models.last_installation_preparation import LastInstallationPreparation
from assisted_service_client.models.list_managed_domains import ListManagedDomains
from assisted_service_client.models.list_manifests import ListManifests
from assisted_service_client.models.list_versions import ListVersions
from assisted_service_client.models.logs_gather_cmd_request import LogsGatherCmdRequest
from assisted_service_client.models.logs_progress_params import LogsProgressParams
from assisted_service_client.models.logs_state import LogsState
from assisted_service_client.models.logs_type import LogsType
from assisted_service_client.models.mac_interface_map import MacInterfaceMap
from assisted_service_client.models.mac_interface_map_inner import MacInterfaceMapInner
from assisted_service_client.models.machine_network import MachineNetwork
from assisted_service_client.models.managed_domain import ManagedDomain
from assisted_service_client.models.manifest import Manifest
from assisted_service_client.models.memory import Memory
from assisted_service_client.models.memory_method import MemoryMethod
from assisted_service_client.models.monitored_operator import MonitoredOperator
from assisted_service_client.models.monitored_operators_list import MonitoredOperatorsList
from assisted_service_client.models.mtu_report import MtuReport
from assisted_service_client.models.next_step_cmd_request import NextStepCmdRequest
from assisted_service_client.models.node_label_params import NodeLabelParams
from assisted_service_client.models.ntp_source import NtpSource
from assisted_service_client.models.ntp_synchronization_request import NtpSynchronizationRequest
from assisted_service_client.models.ntp_synchronization_response import NtpSynchronizationResponse
from assisted_service_client.models.openshift_version import OpenshiftVersion
from assisted_service_client.models.openshift_versions import OpenshiftVersions
from assisted_service_client.models.operator_create_params import OperatorCreateParams
from assisted_service_client.models.operator_hardware_requirements import OperatorHardwareRequirements
from assisted_service_client.models.operator_host_requirements import OperatorHostRequirements
from assisted_service_client.models.operator_monitor_report import OperatorMonitorReport
from assisted_service_client.models.operator_properties import OperatorProperties
from assisted_service_client.models.operator_property import OperatorProperty
from assisted_service_client.models.operator_status import OperatorStatus
from assisted_service_client.models.operator_type import OperatorType
from assisted_service_client.models.os_image import OsImage
from assisted_service_client.models.os_images import OsImages
from assisted_service_client.models.platform import Platform
from assisted_service_client.models.platform_external import PlatformExternal
from assisted_service_client.models.platform_type import PlatformType
from assisted_service_client.models.preflight_hardware_requirements import PreflightHardwareRequirements
from assisted_service_client.models.presigned_url import PresignedUrl
from assisted_service_client.models.proxy import Proxy
from assisted_service_client.models.reboot_for_reclaim_request import RebootForReclaimRequest
from assisted_service_client.models.release_channel import ReleaseChannel
from assisted_service_client.models.release_image import ReleaseImage
from assisted_service_client.models.release_images import ReleaseImages
from assisted_service_client.models.release_source import ReleaseSource
from assisted_service_client.models.release_sources import ReleaseSources
from assisted_service_client.models.route import Route
from assisted_service_client.models.secure_boot_state import SecureBootState
from assisted_service_client.models.service_network import ServiceNetwork
from assisted_service_client.models.source_state import SourceState
from assisted_service_client.models.step import Step
from assisted_service_client.models.step_reply import StepReply
from assisted_service_client.models.step_type import StepType
from assisted_service_client.models.steps import Steps
from assisted_service_client.models.steps_reply import StepsReply
from assisted_service_client.models.subnet import Subnet
from assisted_service_client.models.support_level import SupportLevel
from assisted_service_client.models.support_levels import SupportLevels
from assisted_service_client.models.system_vendor import SystemVendor
from assisted_service_client.models.tang_connectivity_request import TangConnectivityRequest
from assisted_service_client.models.tang_connectivity_response import TangConnectivityResponse
from assisted_service_client.models.tang_connectivity_response_signatures import TangConnectivityResponseSignatures
from assisted_service_client.models.tang_connectivity_response_tang_server_response import TangConnectivityResponseTangServerResponse
from assisted_service_client.models.update_manifest_params import UpdateManifestParams
from assisted_service_client.models.upgrade_agent_request import UpgradeAgentRequest
from assisted_service_client.models.upgrade_agent_response import UpgradeAgentResponse
from assisted_service_client.models.upgrade_agent_result import UpgradeAgentResult
from assisted_service_client.models.upgrade_channel import UpgradeChannel
from assisted_service_client.models.usage import Usage
from assisted_service_client.models.v2_cluster_update_params import V2ClusterUpdateParams
from assisted_service_client.models.verified_vip import VerifiedVip
from assisted_service_client.models.verify_vip import VerifyVip
from assisted_service_client.models.verify_vips_request import VerifyVipsRequest
from assisted_service_client.models.verify_vips_response import VerifyVipsResponse
from assisted_service_client.models.versioned_host_requirements import VersionedHostRequirements
from assisted_service_client.models.versions import Versions
from assisted_service_client.models.vip_type import VipType
from assisted_service_client.models.vip_verification import VipVerification



# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CompletionParams(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_success': 'bool',
        'error_info': 'str',
        'data': 'dict(str, object)'
    }

    attribute_map = {
        'is_success': 'is_success',
        'error_info': 'error_info',
        'data': 'data'
    }

    def __init__(self, is_success=None, error_info=None, data=None):  # noqa: E501
        """CompletionParams - a model defined in Swagger"""  # noqa: E501

        self._is_success = None
        self._error_info = None
        self._data = None
        self.discriminator = None

        self.is_success = is_success
        if error_info is not None:
            self.error_info = error_info
        if data is not None:
            self.data = data

    @property
    def is_success(self):
        """Gets the is_success of this CompletionParams.  # noqa: E501


        :return: The is_success of this CompletionParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_success

    @is_success.setter
    def is_success(self, is_success):
        """Sets the is_success of this CompletionParams.


        :param is_success: The is_success of this CompletionParams.  # noqa: E501
        :type: bool
        """
        if is_success is None:
            raise ValueError("Invalid value for `is_success`, must not be `None`")  # noqa: E501

        self._is_success = is_success

    @property
    def error_info(self):
        """Gets the error_info of this CompletionParams.  # noqa: E501


        :return: The error_info of this CompletionParams.  # noqa: E501
        :rtype: str
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """Sets the error_info of this CompletionParams.


        :param error_info: The error_info of this CompletionParams.  # noqa: E501
        :type: str
        """

        self._error_info = error_info

    @property
    def data(self):
        """Gets the data of this CompletionParams.  # noqa: E501

        additional data from the cluster  # noqa: E501

        :return: The data of this CompletionParams.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this CompletionParams.

        additional data from the cluster  # noqa: E501

        :param data: The data of this CompletionParams.  # noqa: E501
        :type: dict(str, object)
        """

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CompletionParams, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompletionParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
